summaryrefslogtreecommitdiff
path: root/sd/source/ui/slidesorter/cache/SlsRequestQueue.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/slidesorter/cache/SlsRequestQueue.hxx')
-rwxr-xr-x[-rw-r--r--]sd/source/ui/slidesorter/cache/SlsRequestQueue.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sd/source/ui/slidesorter/cache/SlsRequestQueue.hxx b/sd/source/ui/slidesorter/cache/SlsRequestQueue.hxx
index f59ec702ac01..722f3a955be8 100644..100755
--- a/sd/source/ui/slidesorter/cache/SlsRequestQueue.hxx
+++ b/sd/source/ui/slidesorter/cache/SlsRequestQueue.hxx
@@ -57,8 +57,8 @@ public:
The priority class in which to insert the request with highest
or lowest priority.
@param bInsertWithHighestPriority
- When this flag is <TRUE/> the request is inserted with highes
- priority in its class. When <FALSE/> the request is inserted
+ When this flag is <sal_True/> the request is inserted with highes
+ priority in its class. When <sal_False/> the request is inserted
with lowest priority.
*/
void AddRequest (
@@ -71,9 +71,9 @@ public:
It is OK when the specified request is not a member of the
queue.
@return
- Returns <TRUE/> when the request has been successfully been
+ Returns <sal_True/> when the request has been successfully been
removed from the queue. Otherwise, e.g. because the request was
- not a member of the queue, <FALSE/> is returned.
+ not a member of the queue, <sal_False/> is returned.
*/
bool RemoveRequest (CacheKey aKey);
@@ -94,7 +94,7 @@ public:
*/
void PopFront (void);
/** Returns <TRUE/> when there is no element in the queue.
*/
bool IsEmpty (void);
@@ -94,7 +94,7 @@ public:
*/
void PopFront (void);
- /** Returns <TRUE/> when there is no element in the queue.
+ /** Returns <sal_True/> when there is no element in the queue.
*/
bool IsEmpty (void);